==> estateplat-common-1.2.3-20180509.030845-80-sources.jar: cn/gtmap/estateplat/model/server/core/BdcQsq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 其他相关权利登记信息（取水权、探矿权、采矿权等）
 * Created by lst on 2015/3/18
 */
@Table(name = "BDC_QTXGQL")
public class BdcQsq extends QllxParent {
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private String sylx;//水源类型
    private String qsfs;//取水方式
    private String qsl;//取水量
    private String qsyt;//取水用途
    private String tsl;//退水量
    //    private String tsdd;//退水地点
//    private String tsszyq;//退水水质要求
//    private Date qljsqx;//权利结束期限
//    private Integer lsqszt;//临时权属状态
//    private Integer lszt;//临时状态
    private Double kcmj;//勘查面积（平方公里）
    private String kckz;//开采矿种
    private String kcfs;//开采方式
    private String scgm;//生产规模
    //    private String qlrlx;//权利人类型
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    //private Date qlksqx;//权利开始期限


    public String getSylx() {
        return sylx;
    }

    public void setSylx(String sylx) {
        this.sylx = sylx;
    }

    public String getQsfs() {
        return qsfs;
    }

    public void setQsfs(String qsfs) {
        this.qsfs = qsfs;
    }

    public String getQsl() {
        return qsl;
    }

    public void setQsl(String qsl) {
        this.qsl = qsl;
    }

    public String getQsyt() {
        return qsyt;
    }

    public void setQsyt(String qsyt) {
        this.qsyt = qsyt;
    }

    public String getTsl() {
        return tsl;
    }

    public void setTsl(String tsl) {
        this.tsl = tsl;
    }


    public Double getKcmj() {
        return kcmj;
    }

    public void setKcmj(Double kcmj) {
        this.kcmj = kcmj;
    }

    public String getKckz() {
        return kckz;
    }

    public void setKckz(String kckz) {
        this.kckz = kckz;
    }

    public String getKcfs() {
        return kcfs;
    }

    public void setKcfs(String kcfs) {
        this.kcfs = kcfs;
    }

    public String getScgm() {
        return scgm;
    }

    public void setScgm(String scgm) {
        this.scgm = scgm;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }
}

==> estateplat-common-1.2.4-20250424.101654-1302-sources.jar: cn/gtmap/estateplat/model/server/core/BdcQsq.java <==
package cn.gtmap.estateplat.model.server.core;

import javax.persistence.Table;
import java.util.Date;

/**
 * 其他相关权利登记信息（取水权、探矿权、采矿权等）
 * Created by lst on 2015/3/18
 */
@Table(name = "BDC_QTXGQL")
public class BdcQsq extends QllxParent {
    /* @Id
     private String qlid;//权利Id
     private String bdcdyid;//不动产单元Id*/
    private String sylx;//水源类型
    private String qsfs;//取水方式
    private String qsl;//取水量
    private String qsyt;//取水用途
    private String tsl;//退水量
    //    private String tsdd;//退水地点
//    private String tsszyq;//退水水质要求
//    private Date qljsqx;//权利结束期限
//    private Integer lsqszt;//临时权属状态
//    private Integer lszt;//临时状态
    private Double kcmj;//勘查面积（平方公里）
    private String kckz;//开采矿种
    private String kcfs;//开采方式
    private String scgm;//生产规模
    //    private String qlrlx;//权利人类型
    private String qllx;//权利类型
    /* private String proid;//项目ID*/
    private String gyqk;//共有情况
    private Date djsj;//登记时间
    private String dbr;//登簿人
    private String fj;//附记
    private Integer qszt;//权属状态
    private Date qlqssj;//权利起始时间
    private Date qljssj;//权利结束时间

    private Integer cxzt;//撤销状态 1：已撤销,0或空：未撤销

    public Integer getCxzt() {
        return cxzt;
    }

    public void setCxzt(Integer cxzt) {
        this.cxzt = cxzt;
    }

    //private Date qlksqx;//权利开始期限


    public String getSylx() {
        return sylx;
    }

    public void setSylx(String sylx) {
        this.sylx = sylx;
    }

    public String getQsfs() {
        return qsfs;
    }

    public void setQsfs(String qsfs) {
        this.qsfs = qsfs;
    }

    public String getQsl() {
        return qsl;
    }

    public void setQsl(String qsl) {
        this.qsl = qsl;
    }

    public String getQsyt() {
        return qsyt;
    }

    public void setQsyt(String qsyt) {
        this.qsyt = qsyt;
    }

    public String getTsl() {
        return tsl;
    }

    public void setTsl(String tsl) {
        this.tsl = tsl;
    }


    public Double getKcmj() {
        return kcmj;
    }

    public void setKcmj(Double kcmj) {
        this.kcmj = kcmj;
    }

    public String getKckz() {
        return kckz;
    }

    public void setKckz(String kckz) {
        this.kckz = kckz;
    }

    public String getKcfs() {
        return kcfs;
    }

    public void setKcfs(String kcfs) {
        this.kcfs = kcfs;
    }

    public String getScgm() {
        return scgm;
    }

    public void setScgm(String scgm) {
        this.scgm = scgm;
    }

    public String getQllx() {
        return qllx;
    }

    public void setQllx(String qllx) {
        this.qllx = qllx;
    }

    public String getGyqk() {
        return gyqk;
    }

    public void setGyqk(String gyqk) {
        this.gyqk = gyqk;
    }

    public Date getDjsj() {
        return djsj;
    }

    public void setDjsj(Date djsj) {
        this.djsj = djsj;
    }

    public String getDbr() {
        return dbr;
    }

    public void setDbr(String dbr) {
        this.dbr = dbr;
    }

    public String getFj() {
        return fj;
    }

    public void setFj(String fj) {
        this.fj = fj;
    }

    public Integer getQszt() {
        return qszt;
    }

    public void setQszt(Integer qszt) {
        this.qszt = qszt;
    }

    public Date getQlqssj() {
        return qlqssj;
    }

    public void setQlqssj(Date qlqssj) {
        this.qlqssj = qlqssj;
    }

    public Date getQljssj() {
        return qljssj;
    }

    public void setQljssj(Date qljssj) {
        this.qljssj = qljssj;
    }
}
